Changing org.onlab.onos package to org.onosproject

Change-Id: Ic81421faa27acdcff045add47d9e0a715cd4f575
diff --git a/core/net/src/test/java/org/onosproject/core/impl/DummyIdBlockAllocator.java b/core/net/src/test/java/org/onosproject/core/impl/DummyIdBlockAllocator.java
index d4c0e64..3872b97 100644
--- a/core/net/src/test/java/org/onosproject/core/impl/DummyIdBlockAllocator.java
+++ b/core/net/src/test/java/org/onosproject/core/impl/DummyIdBlockAllocator.java
@@ -1,6 +1,6 @@
-package org.onlab.onos.core.impl;
+package org.onosproject.core.impl;
 
-import org.onlab.onos.core.IdBlock;
+import org.onosproject.core.IdBlock;
 
 public class DummyIdBlockAllocator implements IdBlockAllocator {
     private long blockTop;
diff --git a/core/net/src/test/java/org/onosproject/core/impl/TestCoreManager.java b/core/net/src/test/java/org/onosproject/core/impl/TestCoreManager.java
index 7b5fbb2..846696e 100644
--- a/core/net/src/test/java/org/onosproject/core/impl/TestCoreManager.java
+++ b/core/net/src/test/java/org/onosproject/core/impl/TestCoreManager.java
@@ -1,9 +1,9 @@
-package org.onlab.onos.core.impl;
+package org.onosproject.core.impl;
 
-import org.onlab.onos.core.ApplicationId;
-import org.onlab.onos.core.CoreService;
-import org.onlab.onos.core.IdGenerator;
-import org.onlab.onos.core.Version;
+import org.onosproject.core.ApplicationId;
+import org.onosproject.core.CoreService;
+import org.onosproject.core.IdGenerator;
+import org.onosproject.core.Version;
 
 import java.util.Set;
diff --git a/core/net/src/test/java/org/onosproject/core/impl/IdBlockAllocatorBasedIdGeneratorTest.java b/core/net/src/test/java/org/onosproject/core/impl/IdBlockAllocatorBasedIdGeneratorTest.java
index 07d30ca..f0fdcbf 100644
--- a/core/net/src/test/java/org/onosproject/core/impl/IdBlockAllocatorBasedIdGeneratorTest.java
+++ b/core/net/src/test/java/org/onosproject/core/impl/IdBlockAllocatorBasedIdGeneratorTest.java
@@ -1,14 +1,14 @@
-package org.onlab.onos.core.impl;
+package org.onosproject.core.impl;
 
 import org.easymock.EasyMock;
 import org.hamcrest.Matchers;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
-import org.onlab.onos.core.IdBlock;
+import org.onosproject.core.IdBlock;
 
 /**
  * Suites of test of {@link org.onlab.onos.core.impl.BlockAllocatorBasedIdGenerator}.
  */
 public class IdBlockAllocatorBasedIdGeneratorTest {
     private IdBlockAllocator allocator;
@@ -21,7 +21,7 @@
     }
 
     /**
-     * Tests generated IntentId sequences using two {@link org.onlab.onos.core.IdBlock blocks}.
+     * Tests generated IntentId sequences using two {@link org.onosproject.core.IdBlock blocks}.
      */
     @Test
     public void testIds() {
@@ -1,14 +1,14 @@
 
 /**
- * Suites of test of {@link org.onlab.onos.core.impl.BlockAllocatorBasedIdGenerator}.
+ * Suites of test of {@link org.onosproject.core.impl.BlockAllocatorBasedIdGenerator}.
  */
 public class IdBlockAllocatorBasedIdGeneratorTest {